@@ -72,7 +72,7 @@ def add_images_to_existing_project(session, projnumber):
                 int_artist = select_artist(project_team, users, "Select INT artist")
             else:
                 int_artist = project_team[0]
-            if interior_shots is None and num_exist_int == 0:
+            if interior_shots is None:
                 print(
                     f"{existing_project['name']} has no INT images, let's create a folder for them!")
                 int_folder = session.create(
